@@ -5,7 +5,7 @@ from .agent import Agent, Tool
 
 from .browser import (
     Browser,
-    Session,
+    Context,
     Page,
     Element,
 )
@@ -26,7 +26,7 @@ from .llm import (
 
 from ._internal.agent.task_execution import TaskExecution, TaskResult
 
-__version__ = "0.15.0"
+__version__ = "0.16.0"
 
 __all__ = [
     # Manager
@@ -38,7 +38,7 @@ __all__ = [
     "TaskResult",
     # Browser interfaces (for custom implementations)
     "Browser",
-    "Session",
+    "Context",
     "Page",
     "Element",
     # LLM interface
