@@ -3,10 +3,10 @@
 import logging
 from typing import Dict, List, Optional
 from webtask.llm import LLM
-from webtask.browser import Page, Session
+from webtask.browser import Page, Context
 from webtask._internal.agent.session_browser import SessionBrowser
 from webtask._internal.natural_selector import NaturalSelector
-from webtask._internal.agent.task_execution import TaskExecution
+from webtask._internal.agent.task_execution import TaskResult
 from webtask._internal.agent.task_executor import TaskExecutor
 from webtask._internal.utils.wait import wait as custom_wait
 
@@ -15,7 +15,7 @@ class Agent:
     """
     Main agent interface for web automation.
 
-    Requires a Session for browser management and page operations.
+    Requires a Context for browser management and page operations.
 
     Two modes of operation:
     - High-level autonomous: execute(task) - Agent autonomously executes with Worker/Verifier loop
@@ -25,35 +25,39 @@ class Agent:
     def __init__(
         self,
         llm: LLM,
-        session: Optional[Session] = None,
+        context: Optional[Context] = None,
         wait_after_action: float = 0.2,
         use_screenshot: bool = True,
         selector_llm: Optional[LLM] = None,
+        mode: str = "accessibility",
     ):
         """
         Initialize agent.
 
         Args:
             llm: LLM instance for reasoning (task planning, completion checking)
-            session: Optional session instance (can be set later with set_session())
+            context: Optional context instance (can be set later with set_context())
             wait_after_action: Wait time in seconds after each action (default: 0.2)
             use_screenshot: Use screenshots with bounding boxes in LLM context (default: True)
             selector_llm: Optional separate LLM for element selection (defaults to main llm)
+            mode: DOM context mode - "accessibility" (default) or "dom"
         """
         self.llm = llm
-        self.session = session
+        self.context = context
         self.use_screenshot = use_screenshot
         self.wait_after_action = wait_after_action
+        self.mode = mode
         self.logger = logging.getLogger(__name__)
 
         self.session_browser = SessionBrowser(
-            session=session, use_screenshot=use_screenshot
+            context=context, use_screenshot=use_screenshot
         )
 
         self._selector = NaturalSelector(
             llm=selector_llm or llm,
             session_browser=self.session_browser,
             include_screenshot=False,
+            mode=mode,
         )
 
     async def execute(
@@ -61,7 +65,9 @@ class Agent:
         task_description: str,
         max_correction_attempts: int = 3,
         resources: Optional[Dict[str, str]] = None,
-    ) -> TaskExecution:
+        wait_after_action: Optional[float] = None,
+        mode: Optional[str] = None,
+    ) -> TaskResult:
         """
         Execute a task autonomously using Worker/Verifier loop.
 
@@ -69,21 +75,34 @@ class Agent:
             task_description: Task description in natural language
             max_correction_attempts: Maximum correction retry attempts (default: 3)
             resources: Optional dict of file resources (name -> path)
+            wait_after_action: Wait time in seconds after each action (overrides agent default if provided)
+            mode: DOM context mode - "accessibility" or "dom" (overrides agent default if provided)
 
         Returns:
-            TaskExecution object with execution history and final result
+            TaskResult with status, output, feedback, and execution history
 
         Raises:
-            RuntimeError: If no session is available
+            RuntimeError: If no context is available
         """
         if not self.session_browser.get_current_page():
-            raise RuntimeError("No session available. Call set_session() first.")
+            await self.session_browser.create_page()
+
+        # Use task-level wait_after_action if provided, otherwise use agent default
+        effective_wait = (
+            wait_after_action
+            if wait_after_action is not None
+            else self.wait_after_action
+        )
+
+        # Use task-level mode if provided, otherwise use agent default
+        effective_mode = mode if mode is not None else self.mode
 
         task_executor = TaskExecutor(
             llm=self.llm,
             session_browser=self.session_browser,
-            wait_after_action=self.wait_after_action,
+            wait_after_action=effective_wait,
             resources=resources,
+            mode=effective_mode,
         )
 
         result = await task_executor.run(
@@ -104,7 +123,7 @@ class Agent:
             The new Page instance
 
         Raises:
-            RuntimeError: If no session is available
+            RuntimeError: If no context is available
         """
         return await self.session_browser.create_page(url)
 
@@ -162,18 +181,18 @@ class Agent:
         """
         return await self._selector.select(description)
 
-    async def wait_for_idle(self, timeout: int = 30000):
+    async def wait_for_load(self, timeout: int = 10000):
         """
-        Wait for page to be idle (network and DOM stable).
+        Wait for page to fully load.
 
         Args:
-            timeout: Maximum time to wait in milliseconds (default: 30000ms)
+            timeout: Maximum time to wait in milliseconds (default: 10000ms)
 
         Raises:
             RuntimeError: If no page is opened
-            TimeoutError: If page doesn't become idle within timeout
+            TimeoutError: If page doesn't load within timeout
         """
-        await self.session_browser.wait_for_idle(timeout=timeout)
+        await self.session_browser.wait_for_load(timeout=timeout)
 
     async def wait(self, seconds: float):
         """
@@ -213,21 +232,21 @@ class Agent:
         """
         self.session_browser.set_page(page)
 
-    def set_session(self, session: Session) -> None:
+    def set_context(self, context: Context) -> None:
         """
-        Set or update the session.
+        Set or update the context.
 
         Enables multi-page operations after initialization.
 
         Args:
-            session: Session instance for creating pages
+            context: Context instance for creating pages
         """
-        self.session = session
-        self.session_browser.set_session(session)
+        self.context = context
+        self.session_browser.set_context(context)
 
     async def close(self) -> None:
         """Close the agent and cleanup all resources."""
         await self.session_browser.close()
 
-        if self.session:
-            await self.session.close()
+        if self.context:
+            await self.context.close()
