@@ -1,9 +1,7 @@
 """LLM integrations."""
 
-from .openai import OpenAILLM
 from .google import GeminiLLM
 
 __all__ = [
-    "OpenAILLM",
     "GeminiLLM",
 ]
